@@ -166,6 +166,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
         mPresetsCombo->addItem(i18nc("@item:inlistbox", "1 week"), 7*1440);
         mPresetsCombo->setCurrentIndex(-1);
         connect(mPresetsCombo, &ComboBox::activated, this, &AlarmTimeWidget::slotPresetSelected);
+        mPresetsCombo->setToolTip(i18nc("@info:tooltip", "Select time delay from a list of preset values"));
     }
     else
     {
@@ -535,7 +536,15 @@ void AlarmTimeWidget::setAnyTime()
 }
 
 /******************************************************************************
-* Enable/disable the "date only" radio button.
+* Return whether the "date only" checkbox is selected.
+*/
+bool AlarmTimeWidget::anyTimeSelected() const
+{
+    return mAnyTimeCheckBox && mAnyTimeCheckBox->isChecked();
+}
+
+/******************************************************************************
+* Enable/disable the "date only" checkbox.
 */
 void AlarmTimeWidget::enableAnyTime(bool enable)
 {
@@ -793,4 +802,6 @@ void AlarmTimeWidget::slotPresetSelected(int index)
     mPresetsCombo->blockSignals(false);
 }
 
+#include "moc_alarmtimewidget.cpp"
+
 // vim: et sw=4:
