@@ -1,7 +1,7 @@
 /*
  *  prefdlg_p.h  -  private classes for program preferences dialog
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -60,7 +60,7 @@ private:
     static int       mIndentWidth;           // indent width for checkboxes etc.
     static int       mGridIndentWidth;       // minimum grid column indent width for checkboxes etc.
     QVBoxLayout*     mTopLayout;
-    QVector<QLabel*> mLabels;                // labels to right-align
+    QList<QLabel*>   mLabels;                // labels to right-align
     bool             mLabelsAligned {false}; // labels have been aligned
 };
 
@@ -110,6 +110,7 @@ private:
     QComboBox*    mHolidays;
     QMap<QString, QString> mHolidayNames;
     TimeEdit*     mStartOfDay;
+    SpinBox*      mPreWakeSuspend {nullptr};
     QCheckBox*    mWorkDays[7];
     TimeEdit*     mWorkStart;
     TimeEdit*     mWorkEnd;
@@ -269,7 +270,7 @@ private:
     QCheckBox*    mTooltipShowTimeTo;
     QLineEdit*    mTooltipTimeToPrefix;
     QLabel*       mTooltipTimeToPrefixLabel;
-    ButtonGroup*  mWindowPosition {nullptr};
+    ButtonGroup*  mWindowPosition;
     QSpinBox*     mWindowButtonDelay;
     QLabel*       mWindowButtonDelayLabel;
     QCheckBox*    mModalMessages {nullptr};
