@@ -2,7 +2,7 @@
  *  singlefileresource.cpp  -  calendar resource held in a single file
  *  Program:  kalarm
  *  Partly based on ICalResourceBase and SingleFileResource in kdepim-runtime.
- *  SPDX-FileCopyrightText: 2009-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2009-2023 David Jarvie <djarvie@kde.org>
  *  SPDX-FileCopyrightText: 2008 Bertjan Broeksema <broeksema@kde.org>
  *  SPDX-FileCopyrightText: 2008 Volker Krause <vkrause@kde.org>
  *  SPDX-FileCopyrightText: 2006 Till Adam <adam@kde.org>
@@ -208,8 +208,8 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
             // never be reached!
             qCWarning(KALARM_LOG) << "SingleFileResource::load:" << displayId() << "Error? File location changed to" << localFileName;
             setLoadFailure(true, Status::NotConfigured);
-            mFileStorage.clear();
-            mCalendar.clear();
+            mFileStorage.reset();
+            mCalendar.reset();
             mLoadedEvents.clear();
         }
 
@@ -430,8 +430,8 @@ void SingleFileResource::close()
 
     if (mSettings  &&  mSettings->url().isLocalFile())
         KDirWatch::self()->removeFile(mSettings->url().toLocalFile());
-    mCalendar.clear();
-    mFileStorage.clear();
+    mCalendar.reset();
+    mFileStorage.reset();
     setStatus(Status::Closed);
 }
 
@@ -457,7 +457,7 @@ bool SingleFileResource::doAddEvent(const KAEvent& event)
     }
 
     KCalendarCore::Event::Ptr kcalEvent(new KCalendarCore::Event);
-    event.updateKCalEvent(kcalEvent, KAEvent::UID_SET);
+    event.updateKCalEvent(kcalEvent, KAEvent::UidAction::Set);
     if (!mCalendar->addEvent(kcalEvent))
     {
         qCCritical(KALARM_LOG) << "SingleFileResource::addEvent:" << displayId() << "Error adding event with id" << event.id();
@@ -513,7 +513,7 @@ bool SingleFileResource::doUpdateEvent(const KAEvent& event)
 
     // Update the event in place.
     mCalendar->deleteEventInstances(calEvent);
-    event.updateKCalEvent(calEvent, KAEvent::UID_SET);
+    event.updateKCalEvent(calEvent, KAEvent::UidAction::Set);
     mCalendar->setModified(true);
     return true;
 }
@@ -832,4 +832,6 @@ void SingleFileResource::handleSettingsChange(Changes& changes)
     FileResource::handleSettingsChange(changes);
 }
 
+#include "moc_singlefileresource.cpp"
+
 // vim: et sw=4:
