@@ -15,8 +15,6 @@
 
 #include <QTimer>
 
-#include <kwidgetsaddons_version.h>
-
 using namespace KAlarmCal;
 
 namespace
@@ -38,11 +36,7 @@ SingleFileResourceConfigDialog::SingleFileResourceConfigDialog(bool create, QWid
         mUi->alarmTypeLabel->setVisible(false);
 
         mUi->pathRequester->setMode(KFile::File);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 108, 0)
         mUi->pathRequester->setNameFilters({QStringLiteral("%1 (*.ics)").arg(i18nc("@item:inlistbox File type selection filter", "Calendar files"))});
-#else
-        mUi->pathRequester->setFilter(QStringLiteral("*.ics|%1").arg(i18nc("@item:inlistbox File type selection filter", "Calendar files")));
-#endif
         mUi->pathRequester->setFocus();
         mUi->statusLabel->setText(QString());
         connect(mUi->pathRequester, &KUrlRequester::textChanged, this, &SingleFileResourceConfigDialog::validate);
@@ -249,10 +243,9 @@ void SingleFileResourceConfigDialog::slotStatJobResult(KJob* job)
 */
 void SingleFileResourceConfigDialog::initiateUrlStatusCheck(const QUrl& url)
 {
-    mStatJob = KIO::statDetails(url,
-                                KIO::StatJob::SourceSide,
-                                KIO::StatDetail::StatDefaultDetails,
-                                KIO::HideProgressInfo);
+    mStatJob = KIO::stat(url, KIO::StatJob::SourceSide,
+                              KIO::StatDetail::StatDefaultDetails,
+                              KIO::HideProgressInfo);
     connect(mStatJob, &KIO::StatJob::result, this, &SingleFileResourceConfigDialog::slotStatJobResult);
 }
 
@@ -312,4 +305,6 @@ void setTextEditHeight(KTextEdit* textEdit, QGroupBox* groupBox)
 
 }
 
+#include "moc_singlefileresourceconfigdialog.cpp"
+
 // vim: et sw=4:
