@@ -1,7 +1,7 @@
 /*
  *  resourcescalendar.cpp  -  KAlarm calendar resources access
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -9,6 +9,7 @@
 #include "resourcescalendar.h"
 
 #include "eventid.h"
+#include "kalarmapp.h"
 #include "resources/resources.h"
 #include "kalarm_debug.h"
 
@@ -24,6 +25,7 @@ ResourcesCalendar::EarliestMap ResourcesCalendar::mEarliestNonDispAlarm;
 QSet<QString>                  ResourcesCalendar::mPendingAlarms;
 bool                           ResourcesCalendar::mIgnoreAtLogin {false};
 bool                           ResourcesCalendar::mHaveDisabledAlarms {false};
+QHash<ResourceId, QHash<QString, KernelWakeAlarm>> ResourcesCalendar::mWakeSuspendTimers;
 
 
 /******************************************************************************
@@ -61,9 +63,11 @@ ResourcesCalendar::ResourcesCalendar()
     connect(resources, &Resources::eventUpdated, this, &ResourcesCalendar::slotEventUpdated);
     connect(resources, &Resources::resourcesPopulated, this, &ResourcesCalendar::slotResourcesPopulated);
     connect(resources, &Resources::settingsChanged, this, &ResourcesCalendar::slotResourceSettingsChanged);
+    connect(theApp(), &KAlarmApp::alarmEnabledToggled, this, &ResourcesCalendar::slotAlarmsEnabledToggled);
+    Preferences::connect(&Preferences::wakeFromSuspendAdvanceChanged, this, &ResourcesCalendar::slotWakeFromSuspendAdvanceChanged);
 
     // Fetch events from all resources which already exist.
-    QVector<Resource> allResources = Resources::enabledResources();
+    QList<Resource> allResources = Resources::enabledResources();
     for (Resource& resource : allResources)
         slotResourceAdded(resource);
 }
@@ -193,6 +197,9 @@ void ResourcesCalendar::slotEventUpdated(Resource& resource, const KAEvent& even
     if ((resource.alarmTypes() & CalEvent::ACTIVE)
     &&  event.category() == CalEvent::ACTIVE)
     {
+        // Set/clear wake from suspend timer if needed
+        checkKernelWakeSuspend(key, event);
+
         // Update the earliest alarm to trigger
         const QString earliestId        = mEarliestAlarm.value(key);
         const QString earliestNonDispId = mEarliestNonDispAlarm.value(key);
@@ -200,24 +207,24 @@ void ResourcesCalendar::slotEventUpdated(Resource& resource, const KAEvent& even
             findEarliestAlarm(resource);
         else
         {
-            const KADateTime dt = event.nextTrigger(KAEvent::ALL_TRIGGER).effectiveKDateTime();
+            const KADateTime dt = event.nextTrigger(KAEvent::Trigger::All).effectiveKDateTime();
             if (dt.isValid())
             {
                 bool changed = false;
                 DateTime next;
                 if (!earliestId.isEmpty())
-                    next = resource.event(earliestId).nextTrigger(KAEvent::ALL_TRIGGER);
+                    next = resource.event(earliestId).nextTrigger(KAEvent::Trigger::All);
                 if (earliestId.isEmpty()  ||  dt < next)
                 {
                     mEarliestAlarm[key] = event.id();
                     changed = true;
                 }
-                if (!(event.actionTypes() & KAEvent::ACT_DISPLAY))
+                if (!(event.actionTypes() & KAEvent::Action::Display))
                 {
                     // It is not a display event.
                     DateTime nextNonDisp;
                     if (!earliestNonDispId.isEmpty())
-                        nextNonDisp = (earliestId == earliestNonDispId) ? next : resource.event(earliestNonDispId).nextTrigger(KAEvent::ALL_TRIGGER);
+                        nextNonDisp = (earliestId == earliestNonDispId) ? next : resource.event(earliestNonDispId).nextTrigger(KAEvent::Trigger::All);
                     if (earliestNonDispId.isEmpty()  ||  dt < nextNonDisp)
                     {
                         mEarliestNonDispAlarm[key] = event.id();
@@ -253,13 +260,54 @@ void ResourcesCalendar::slotEventsToBeRemoved(Resource& resource, const QList<KA
     }
 }
 
+/******************************************************************************
+* Called when alarm monitoring has been enabled or disabled (for all alarms).
+* Arm or disarm kernel wake alarms for all events which use them.
+*/
+void ResourcesCalendar::slotAlarmsEnabledToggled(bool enabled)
+{
+    if (!KernelWakeAlarm::isAvailable())
+        return;
+
+    if (enabled)
+    {
+        // Set kernel wake timers for all events which require them.
+        setKernelWakeSuspend();
+    }
+    else
+    {
+        // Disarm all kernel wake timers (but don't delete them).
+        for (auto itr = mWakeSuspendTimers.begin(), endr = mWakeSuspendTimers.end();  itr != endr;  ++itr)
+        {
+            auto& resourceHash = itr.value();
+            for (auto it = resourceHash.begin(), end = resourceHash.end();  it != end;  ++it)
+                it.value().disarm();
+        }
+    }
+}
+
+/******************************************************************************
+* Called when the wake-from-suspend wakeup advance interval has changed.
+* Revise all kernel wake alarm times.
+* Note that the user only has the option to change the wakeup advance if kernel
+* wake alarms are used, and not if the RTC wake timer is used.
+*/
+void ResourcesCalendar::slotWakeFromSuspendAdvanceChanged(unsigned advance)
+{
+    if (!KernelWakeAlarm::isAvailable()  ||  !theApp()->alarmsEnabled())
+        return;
+
+    qCDebug(KALARM_LOG) << "ResourcesCalendar::slotWakeFromSuspendAdvanceChanged:" << advance;
+    setKernelWakeSuspend();
+}
+
 /******************************************************************************
 * This method must only be called from the main KAlarm queue processing loop,
 * to prevent asynchronous calendar operations interfering with one another.
 *
 * Purge a list of archived events from the calendar.
 */
-void ResourcesCalendar::purgeEvents(const QVector<KAEvent>& events)
+void ResourcesCalendar::purgeEvents(const QList<KAEvent>& events)
 {
     for (const KAEvent& event : events)
     {
@@ -403,7 +451,11 @@ KAEvent ResourcesCalendar::updateEvent(const KAEvent& evnt, bool saveIfReadOnly)
     {
         Resource resource = Resources::resource(evnt.resourceId());
         if (resource.updateEvent(evnt, saveIfReadOnly))
+        {
+            // Set/clear wake from suspend timer if needed
+            checkKernelWakeSuspend(resource.id(), evnt);
             return evnt;
+        }
     }
     qCDebug(KALARM_LOG) << "ResourcesCalendar::updateEvent: error" << evnt.id();
     return {};
@@ -460,6 +512,10 @@ CalEvent::Type ResourcesCalendar::deleteEventInternal(const KAEvent& event, Reso
 CalEvent::Type ResourcesCalendar::deleteEventInternal(const QString& eventID, const KAEvent& event, Resource& resource, bool deleteFromResource)
 {
     const ResourceId key = resource.id();
+
+    if (mWakeSuspendTimers.contains(key))
+        mWakeSuspendTimers[key].remove(eventID);   // this cancels the timer
+
     mResourceMap[key].remove(eventID);
     if (mEarliestAlarm.value(key)        == eventID
     ||  mEarliestNonDispAlarm.value(key) == eventID)
@@ -489,7 +545,7 @@ KAEvent ResourcesCalendar::event(const EventId& uniqueID, bool findUniqueId)
     {
         // The resource isn't known, but use the event ID if it is unique among
         // all resources.
-        const QVector<KAEvent> list = events(eventId);
+        const QList<KAEvent> list = events(eventId);
         if (list.count() > 1)
         {
             qCWarning(KALARM_LOG) << "ResourcesCalendar::event: Multiple events found with ID" << eventId;
@@ -514,7 +570,7 @@ KAEvent ResourcesCalendar::templateEvent(const QString& templateName)
 {
     if (templateName.isEmpty())
         return {};
-    const QVector<KAEvent> eventlist = events(CalEvent::TEMPLATE);
+    const QList<KAEvent> eventlist = events(CalEvent::TEMPLATE);
     for (const KAEvent& event : eventlist)
     {
         if (event.name() == templateName)
@@ -526,9 +582,9 @@ KAEvent ResourcesCalendar::templateEvent(const QString& templateName)
 /******************************************************************************
 * Return all events with the specified ID, from all calendars.
 */
-QVector<KAEvent> ResourcesCalendar::events(const QString& uniqueId)
+QList<KAEvent> ResourcesCalendar::events(const QString& uniqueId)
 {
-    QVector<KAEvent> list;
+    QList<KAEvent> list;
     for (ResourceMap::ConstIterator rit = mResourceMap.constBegin();  rit != mResourceMap.constEnd();  ++rit)
     {
         if (rit.value().contains(uniqueId))
@@ -537,27 +593,27 @@ QVector<KAEvent> ResourcesCalendar::events(const QString& uniqueId)
     return list;
 }
 
-QVector<KAEvent> ResourcesCalendar::events(const Resource& resource, CalEvent::Types type)
+QList<KAEvent> ResourcesCalendar::events(const Resource& resource, CalEvent::Types type)
 {
     return events(type, resource);
 }
 
-QVector<KAEvent> ResourcesCalendar::events(CalEvent::Types type)
+QList<KAEvent> ResourcesCalendar::events(CalEvent::Types type)
 {
     Resource resource;
     return events(type, resource);
 }
 
-QVector<KAEvent> ResourcesCalendar::events(CalEvent::Types type, const Resource& resource)
+QList<KAEvent> ResourcesCalendar::events(CalEvent::Types type, const Resource& resource)
 {
-    QVector<KAEvent> list;
+    QList<KAEvent> list;
     if (resource.isValid())
     {
         const ResourceId key = resource.id();
         ResourceMap::ConstIterator rit = mResourceMap.constFind(key);
         if (rit == mResourceMap.constEnd())
             return list;
-        const QVector<KAEvent> events = eventsForResource(resource, rit.value());
+        const QList<KAEvent> events = eventsForResource(resource, rit.value());
         if (type == CalEvent::EMPTY)
             return events;
         for (const KAEvent& event : events)
@@ -569,7 +625,7 @@ QVector<KAEvent> ResourcesCalendar::events(CalEvent::Types type, const Resource&
         for (ResourceMap::ConstIterator rit = mResourceMap.constBegin();  rit != mResourceMap.constEnd();  ++rit)
         {
             const Resource res = Resources::resource(rit.key());
-            const QVector<KAEvent> events = eventsForResource(res, rit.value());
+            const QList<KAEvent> events = eventsForResource(res, rit.value());
             if (type == CalEvent::EMPTY)
                 list += events;
             else
@@ -619,7 +675,7 @@ void ResourcesCalendar::checkForDisabledAlarms(bool oldEnabled, bool newEnabled)
 void ResourcesCalendar::checkForDisabledAlarms()
 {
     bool disabled = false;
-    const QVector<KAEvent> eventlist = events(CalEvent::ACTIVE);
+    const QList<KAEvent> eventlist = events(CalEvent::ACTIVE);
     for (const KAEvent& event : eventlist)
     {
         if (!event.enabled())
@@ -635,6 +691,48 @@ void ResourcesCalendar::checkForDisabledAlarms()
     }
 }
 
+/******************************************************************************
+* Set kernel wake alarm timers for all events which require them.
+*/
+void ResourcesCalendar::setKernelWakeSuspend()
+{
+    for (auto itr = mWakeSuspendTimers.begin(), endr = mWakeSuspendTimers.end();  itr != endr;  ++itr)
+    {
+        const ResourceId resourceId = itr.key();
+        Resource resource = Resources::resource(resourceId);
+        auto& resourceHash = itr.value();
+        for (auto it = resourceHash.begin(), end = resourceHash.end();  it != end;  ++it)
+        {
+            const KAEvent event = resource.event(it.key());
+            checkKernelWakeSuspend(resourceId, event);
+        }
+    }
+}
+
+/******************************************************************************
+* Set or clear any kernel wake alarm associated with an event.
+*/
+void ResourcesCalendar::checkKernelWakeSuspend(ResourceId key, const KAEvent& event)
+{
+    if (KernelWakeAlarm::isAvailable()  &&  event.enabled()  &&  event.wakeFromSuspend())
+    {
+        const KADateTime dt = event.nextDateTime(KAEvent::NextWorkHoliday).kDateTime();
+        if (!dt.isDateOnly())   // can't determine a wakeup time for date-only events
+        {
+            KernelWakeAlarm& kernelAlarm = mWakeSuspendTimers[key][event.id()];
+            if (theApp()->alarmsEnabled())
+                kernelAlarm.arm(dt.addSecs(static_cast<int>(Preferences::wakeFromSuspendAdvance()) * -60));
+            else
+                kernelAlarm.disarm();
+        }
+    }
+    else
+    {
+        if (mWakeSuspendTimers.contains(key))
+            mWakeSuspendTimers[key].remove(event.id());   // this cancels the timer
+    }
+}
+
 /******************************************************************************
 * Find and note the active alarm with the earliest trigger time for a calendar,
 * and the non-display active alarm with the earliest trigger time.
@@ -658,7 +756,7 @@ void ResourcesCalendar::findEarliestAlarm(const Resource& resource)
     ResourceMap::ConstIterator rit = mResourceMap.constFind(key);
     if (rit == mResourceMap.constEnd())
         return;
-    const QVector<KAEvent> events = eventsForResource(resource, rit.value());
+    const QList<KAEvent> events = eventsForResource(resource, rit.value());
     KAEvent earliest, earliestNonDisp;
     KADateTime earliestTime, earliestNonDispTime;
     for (const KAEvent& event : events)
@@ -666,7 +764,7 @@ void ResourcesCalendar::findEarliestAlarm(const Resource& resource)
         if (event.category() != CalEvent::ACTIVE
         ||  mPendingAlarms.contains(event.id()))
             continue;
-        const KADateTime dt = event.nextTrigger(KAEvent::ALL_TRIGGER).effectiveKDateTime();
+        const KADateTime dt = event.nextTrigger(KAEvent::Trigger::All).effectiveKDateTime();
         if (dt.isValid())
         {
             if (!earliest.isValid() || dt < earliestTime)
@@ -674,7 +772,7 @@ void ResourcesCalendar::findEarliestAlarm(const Resource& resource)
                 earliestTime = dt;
                 earliest = event;
             }
-            if (!(event.actionTypes() & KAEvent::ACT_DISPLAY))
+            if (!(event.actionTypes() & KAEvent::Action::Display))
             {
                 if (!earliestNonDisp.isValid() || dt < earliestNonDispTime)
                 {
@@ -713,7 +811,7 @@ KAEvent ResourcesCalendar::earliestAlarm(KADateTime& nextTriggerTime, bool exclu
             return earliestAlarm(nextTriggerTime, excludeDisplayAlarms);
         }
 //TODO: use next trigger calculated in findEarliestAlarm() (allowing for it being out of date)?
-        const KADateTime dt = event.nextTrigger(KAEvent::ALL_TRIGGER).effectiveKDateTime();
+        const KADateTime dt = event.nextTrigger(KAEvent::Trigger::All).effectiveKDateTime();
         if (dt.isValid()  &&  (!earliest.isValid() || dt < earliestTime))
         {
             earliestTime = dt;
@@ -752,13 +850,15 @@ void ResourcesCalendar::setAlarmPending(const KAEvent& event, bool pending)
 /******************************************************************************
 * Get the events for a list of event IDs.
 */
-QVector<KAEvent> ResourcesCalendar::eventsForResource(const Resource& resource, const QSet<QString>& eventIds)
+QList<KAEvent> ResourcesCalendar::eventsForResource(const Resource& resource, const QSet<QString>& eventIds)
 {
-    QVector<KAEvent> events;
+    QList<KAEvent> events;
     events.reserve(eventIds.count());
     for (const QString& eventId : eventIds)
         events += resource.event(eventId);
     return events;
 }
 
+#include "moc_resourcescalendar.cpp"
+
 // vim: et sw=4:
